\name{multires}
\alias{multires}
\title{Multiresolution analysis of a 1D signal}
\description{Use simple filter banks to produce bandpass-filtered
signals at multiple level of resolutions, doubling the scale with
each increasing level.}
\usage{
multires(y,K=NULL)
}
\arguments{
\item{y}{The signal}
\item{K}{Number of levels. By default, \code{K=ceiling(log2(length(y)))}.}
}
\value{A matrix of K columns; and the same number of rows as the input 
signal lengtgh. Visualize using \link{mrplot}}
\seealso{mrplot,extremepoints}
\examples{
## assume we have the 'clust' output (see coldmap)

mr <- multires( clust$cclust$leaf.corr )
mrplot( cbind(clust$cclust$leaf.corr, mr), ylim=c(0,max(mr)), input = 1 )

# to analyze indivudual plot, say at 8th level
plot( mr[,8], type="l")
ep <- extremepoints( mr[,8] )
points( ep$pos[ep$val > 0], ep$val[ep$val > 0], col="red")

# lookup what genes was the center
peaks <- ep$pos[ep$val > 0]

# make ordered genes
ogene <- clust$cclust$labels[clust$cclust$order]
ogene[peaks]

# 21 genes surrounding the 29th peak
ogene[ (peaks[29]-10):(peaks[29]+10) ]
}
