\name{pwmap}
\alias{pwmap}
\title{Heatmap of pairwise correlation matrix}
\description{Show heatmap(s) of pairwise correlation matrices that are
optionally produced by \code{coldmap} and \code{nclust2}. When multiple
datasets are used, the pairwise correlation matrix of the samples
are stratified according to datasets. The column clustering is still
shown as a single matrix.}
\usage{
pwmap( C,  dlab=NULL, col=rb.colors, saturation=.666,
  gutter = NULL, proportional=TRUE,
  rdw = 3, cdw = 3, stratify = TRUE, hang=.05, ticks=NULL )
}
\arguments{
\item{C}{A clustering object, either the \code{rclust} or \code{cclust} part
of \code{nclust2} or \code{coldmap} output}
\item{dlab}{Dataset labels}
\item{col}{Heatmap colors}
\item{saturation}{Color saturation}
\item{gutter}{gap between heatmaps (measured in number of samples). By
default it is one twentieth of the average sample size.}
\item{proportional}{Draw the each heatmap with a height proportional
to the sample size.}
\item{rdw,cdw}{Row (or column) dendrogram width}
\item{stratify}{If false, show one matrix, even if multiple datasets exist.}
\item{hang}{Dendrogram 'hang' option (see \code{dendrolines}}
\item{ticks}{Ticks interval. The default is automatic.}
}
\details{
Most options have the same meaning as in \code{coldmap}. More features
(sparse labeling of the cluster elements, graphical annotations, etc.)
are planned.
}
\seealso{nclust2,coldmap}
\examples{
# assume the output of coldmap() example

pwmap( clust$rclust, dlab=c("TGIF1","JRH2") )
pwmap( clust$rclust, dlab=c("TGIF1","JRH2"), stratify = FALSE )

pwmap( clust$rclust, dlab=c("TGIF1","JRH2"), col=rg.colors )

# if column pairwise matrix is needed, rerun coldmap or nclust2 with
# cpwcorr=TRUE option
}
